<?php
/*
  $Id: password_forgotten.php,v 1.2 2006/07/16 05:09:35 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('NAVBAR_TITLE_1', '');
define('NAVBAR_TITLE_2', 'ѥɤ˺ޤ');
define('HEADING_TITLE', 'ѥɤ˺ޤ!');
define('ENTRY_FORGOTTEN_EMAIL_ADDRESS', 'Ͽ E-Mail ɥ쥹:'); // 2003.03.06 nagata Edit Japanese osCommerce
define('TEXT_NO_EMAIL_ADDRESS_FOUND', '<strong>:</strong> Ϥ줿E-Mail ɥ쥹ϸĤޤǤ⤦ϤƤ');
define('EMAIL_PASSWORD_REMINDER_SUBJECT', STORE_NAME . 'οѥ');
define('EMAIL_PASSWORD_REMINDER_BODY',
'ѥɤȯ԰꤬ ' . $REMOTE_ADDR . ' 餢ޤ' . "\n\n"
. 'ʤ \'' . STORE_NAME . '\' ؤοѥɤ' . "\n"
. '---------------------------------------------------------------------------' . "\n"
. '   %s' . "\n"
. '---------------------------------------------------------------------------' . "\n"
. 'Ȥʤޤ' . "\n\n"
. 'Υ᡼˴ؤƤФʤϡŹޤǤϢ' . "\n\n"
. EMAIL_SIGNATURE);
define('TEXT_PASSWORD_SENT', 'ѥɤϿ E-Mail ɥ쥹ޤ');

define('EMAIL_HONORIFIC', ' ');
?>